@@ -33,6 +33,9 @@ static void         gail_notebook_real_notify_gtk     (GObject           *obj,
 
 static AtkObject*   gail_notebook_ref_child           (AtkObject      *obj,
                                                        gint           i);
+static gint         gail_notebook_real_remove_gtk     (GtkContainer   *container,
+                                                       GtkWidget      *widget,
+                                                       gpointer       data);    
 static void         atk_selection_interface_init      (AtkSelectionIface *iface);
 static gboolean     gail_notebook_add_selection       (AtkSelection   *selection,
                                                        gint           i);
@@ -120,11 +123,7 @@ gail_notebook_class_init (GailNotebookClass *klass)
    * as the implementation in GailContainer returns the correct
    * number of children.
    */
-  /*
-   * We do not emit emit notification of when child is removed as this
-   * is done in gail_notebook_child_parent_set.
-   */
-  container_class->remove_gtk = NULL;
+  container_class->remove_gtk = gail_notebook_real_remove_gtk;
 }
 
 static void
@@ -133,6 +132,7 @@ gail_notebook_object_init (GailNotebook      *notebook)
   notebook->page_cache = NULL;
   notebook->selected_page = -1;
   notebook->focus_tab_page = -1;
+  notebook->remove_index = -1;
   notebook->idle_focus_id = 0;
 }
 
@@ -189,7 +189,6 @@ gail_notebook_real_initialize (AtkObject *obj,
 {
   GailNotebook *notebook;
   GtkNotebook *gtk_notebook;
-  GtkWidget *page;
   gint i;
 
   ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
@@ -463,7 +462,6 @@ check_cache (GailNotebook *gail_notebook,
 {
   GList *gtk_list;
   GList *gail_list;
-  AtkObject *obj;
   gint i;
 
   gtk_list = notebook->children;
@@ -514,18 +512,31 @@ create_notebook_page_accessible (GailNotebook *gail_notebook,
 static void
 gail_notebook_child_parent_set (GtkWidget *widget,
                                 GtkWidget *old_parent,
-                                gpointer  data)
+                                gpointer   data)
+{
+  GailNotebook *gail_notebook;
+
+  g_return_if_fail (old_parent != NULL);
+  gail_notebook = GAIL_NOTEBOOK (gtk_widget_get_accessible (old_parent));
+  gail_notebook->remove_index = GPOINTER_TO_INT (data);
+}
+
+static gint
+gail_notebook_real_remove_gtk (GtkContainer *container,
+                               GtkWidget    *widget,
+                               gpointer      data)    
 {
   GailNotebook *gail_notebook;
   AtkObject *obj;
   gint index;
 
-  g_return_if_fail (old_parent != NULL);
-  gail_notebook = GAIL_NOTEBOOK (gtk_widget_get_accessible (old_parent));
-  index = GPOINTER_TO_INT (data);
+  g_return_val_if_fail (container != NULL, 1);
+  gail_notebook = GAIL_NOTEBOOK (gtk_widget_get_accessible (GTK_WIDGET (container)));
+  index = gail_notebook->remove_index;
+  gail_notebook->remove_index = -1;
 
   obj = find_child_in_list (gail_notebook->page_cache, index);
-  g_return_if_fail (obj);
+  g_return_val_if_fail (obj, 1);
   gail_notebook->page_cache = g_list_remove (gail_notebook->page_cache, obj);
   gail_notebook->page_count -= 1;
   g_signal_emit_by_name (gail_notebook,
@@ -533,6 +544,7 @@ gail_notebook_child_parent_set (GtkWidget *widget,
                           GAIL_NOTEBOOK_PAGE (obj)->index, 
                           obj, NULL);
   g_object_unref (obj);
+  return 1;
 }
 
 static gboolean
