@@ -49,6 +49,9 @@ struct _GailTreeView
   GArray*	row_data;
   GList*        cell_data;
   GtkTreeModel  *tree_model;
+  AtkObject     *focus_cell;
+  GtkAdjustment *old_hadj;
+  GtkAdjustment *old_vadj;
 };
 
 GType gail_tree_view_get_type (void);
@@ -60,6 +63,8 @@ struct _GailTreeViewClass
 
 AtkObject* gail_tree_view_new (GtkWidget *widget);
 
+AtkObject* gail_tree_view_ref_focus_cell (GtkTreeView *treeview);
+ 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
